@@ -8,11 +8,11 @@
 #include "owncloud.h"
 #include "owncloudcontroller.h"
 
-#include <KLocalizedString>
 #include <KDeclarative/QmlObject>
+#include <KLocalizedString>
 
-#include <QQmlEngine>
 #include <QQmlContext>
+#include <QQmlEngine>
 #include <QWindow>
 
 OwnCloudWizard::OwnCloudWizard(QObject *parent)
@@ -28,8 +28,7 @@ OwnCloudWizard::~OwnCloudWizard()
 void OwnCloudWizard::init(KAccountsUiPlugin::UiType type)
 {
     if (type == KAccountsUiPlugin::NewAccountDialog) {
-
-        const QString packagePath("org.kde.kaccounts.owncloud");
+        const QString packagePath(QStringLiteral("org.kde.kaccounts.owncloud"));
 
         m_object = new KDeclarative::QmlObject();
         m_object->setTranslationDomain(packagePath);
@@ -48,7 +47,7 @@ void OwnCloudWizard::init(KAccountsUiPlugin::UiType type)
             Q_EMIT canceled();
         });
 
-        m_object->engine()->rootContext()->setContextProperty("helper", helper);
+        m_object->engine()->rootContext()->setContextProperty(QStringLiteral("helper"), helper);
 
         m_object->completeInitialization();
 
@@ -58,7 +57,6 @@ void OwnCloudWizard::init(KAccountsUiPlugin::UiType type)
 
         Q_EMIT uiReady();
     }
-
 }
 
 void OwnCloudWizard::setProviderName(const QString &providerName)
